@@ -46,7 +46,7 @@ use Sub::Exporter -setup => {
     },
 };
 
-our $VERSION = '0.971.0';
+our $VERSION = '0.971.2';
 
 ### CLASS FUNCTIONS ###
 
@@ -492,7 +492,7 @@ sub insert {
     my @invalid = sort grep { !$urow->can($_) } keys %$values;
     my @vals = map { _bval( $values->{$_}, $urow->$_->_type ) } @cols;
 
-    $log->warn( "columns not in table '$table': @invalid\n    at", caller )
+    $log->debug( "columns not in table '$table': @invalid\n    at", caller )
       if @invalid;
     confess 'insert_into requires columns/values' unless @cols;
 
