@@ -41,7 +41,7 @@ use overload
   fallback => 1,
   ;
 
-our $VERSION = '0.971.0';
+our $VERSION = '0.971.2';
 our $tcount  = {};
 
 # ########################################################################
@@ -294,6 +294,15 @@ sub _sql_values_types {
                 elsif ( $type eq 'bytea' ) {
                     push( @types, { pg_type => eval 'DBD::Pg::PG_BYTEA' } );
                 }
+                elsif ( $type eq 'inet' ) {
+                    push( @types, { pg_type => eval 'DBD::Pg::PG_INET' } );
+                }
+                elsif ( $type eq 'cidr' ) {
+                    push( @types, { pg_type => eval 'DBD::Pg::PG_CIDR' } );
+                }
+                elsif ( $type eq 'boolean' ) {
+                    push( @types, { pg_type => eval 'DBD::Pg::PG_BOOL' } );
+                }
                 else {
                     warn "No mapping for type $type";
                     push( @types, undef );
@@ -304,10 +313,7 @@ sub _sql_values_types {
                 # leave it undefined
             }
             else {
-                warn "No bind type for $val";
-                push( @values, $val );
-                push( @types,  undef );
-                $sql .= '?';
+                $sql .= $dbh->quote($val);
             }
         }
         elsif ( !defined $token ) {
@@ -500,9 +506,10 @@ sub in {
     if ( @_ >= 2 && $_[0] =~ m/^select/i ) {
         return $e1 . " IN (\n" . _query(@_) . ')';
     }
+    my @list = map { ref $_ eq 'ARRAY' ? @$_ : $_ } @_;
     return
       $e1 . ' IN ('
-      . _expr_join( ', ', map { _bval( $_, $e1->_type ) } @_ ) . ')';
+      . _expr_join( ', ', map { _bval( $_, $e1->_type ) } @list ) . ')';
 }
 
 sub not_in {
@@ -510,10 +517,11 @@ sub not_in {
     if ( @_ >= 2 && $_[0] =~ m/^select/i ) {
         return $e1 . " NOT IN (\n" . _query(@_) . ')';
     }
+    my @list = map { ref $_ eq 'ARRAY' ? @$_ : $_ } @_;
     return
         $e1
       . ' NOT IN ('
-      . _expr_join( ', ', map { _bval( $_, $e1->_type ) } @_ ) . ')';
+      . _expr_join( ', ', map { _bval( $_, $e1->_type ) } @list ) . ')';
 }
 
 sub between {
@@ -555,14 +563,11 @@ sub as {
     if ( $e1->_multi > 0 ) {
         my $expr = SQL::DB::Expr->new( _txt => ['('] );
         $expr .= $e1;
-        $expr .= ') AS ';
-        $expr .= _quote($as);
+        $expr .= ') AS "' . $as . '"';
         return $expr;
     }
 
-    my $expr = $e1 . ' AS ';
-    $expr .= _quote($as);
-    return $expr;
+    return $e1 . ' AS "' . $as . '"';
 }
 
 sub like {
